==> resh-5.0.0.16-py3-none-any.whl: reface/line/builder/builder.py <==
from asgiref.sync import async_to_sync

from reface.line.worker import Worker
from resh.utils.settings import conf


class Builder(Worker):
    file = 'building'

    def __init__(self, layer, box, module, channel):
        super(Builder, self).__init__(layer, box, module, channel)
        self.addresses = []
        self.fixed = {}
        self.dali_type = None

    def _run_thread(self, command, *args):
        command = command(self.module, self.channel, *args)
        command.set_step_handler(self.on_step)
        conf.interface = self.box

        self.remove(self.file)
        self.fixed = {}
        self.addresses = []
        self.dali_type = command.domain_name

        self._command = command
        self.on_step('progress', 1)
        self.write(self.file, value={
            'progress': 1,
            'dali_type': command.domain_name,
            'action': command.__class__.__name__
        })
        self._command.exec()

        self.on_step('progress', 100)

    def on_step(self, action, value):
        if action == 'progress':
            self.progress = value
        elif action == 'found':
            self.addresses.append(value)
            self.remove('scan', self._command.domain_name, value)
        elif action == 'fixed':
            if value[0] not in self.fixed:
                self.fixed[value[0]] = []
                self.remove('scan', self._command.domain_name, value[0])
            if value[1] not in self.fixed[value[0]]:
                self.fixed[value[0]].append(value[1])
                self.remove('scan', self._command.domain_name, value[1])

        async_to_sync(self.layer.group_send)(
            self.group,
            {
                'type': 'chat_message',
                'message': {
                    action: value
                }
            }
        )

        self.write(self.file, value={
            'progress': self.progress,
            'addresses': self.addresses,
            'fixed': self.fixed,
            'dali_type': self.dali_type,
            'action': self._command.__class__.__name__
        })

    @property
    def status(self): return self.read(self.file)

    def send_status(self, channel_name):
        async_to_sync(self.layer.send)(channel_name, {
            'type': 'chat_message',
            'message': {
                'status': self.status
            }
        })

==> resh-5.1.0.9-py3-none-any.whl: reface/line/builder/builder.py <==
from asgiref.sync import async_to_sync
from dali.exceptions import NoFreeAddress

from reface.line.worker import Worker
from resh.utils.settings import conf


class Builder(Worker):
    file = 'building'

    def __init__(self, layer, box, module, channel):
        super(Builder, self).__init__(layer, box, module, channel)
        self.addresses = []
        self.fixed = {}
        self.dali_type = None
        self.error = ''

    def _run_thread(self, command, *args):
        command = command(self.module, self.channel, *args)
        command.set_step_handler(self.on_step)
        conf.interface = self.box

        self.remove(self.file)
        self.fixed = {}
        self.addresses = []
        self.error = ''
        self.dali_type = command.domain_name

        self._command = command
        self.on_step('progress', 1)
        self.write(self.file, value={
            'progress': 1,
            'dali_type': command.domain_name,
            'action': command.__class__.__name__
        })
        try:
            self._command.exec()
        except NoFreeAddress:
            self.on_step('error', 'Обнаружено устройств больше чем 64! Сбор линии прерван')
        except BaseException as ex:
            print(str(ex) if str(ex) else ex.__class__.__name__)
            self.on_step('error', str(ex) if str(ex) else ex.__class__.__name__)
        finally:
            self.on_step('progress', 100)

    def on_step(self, action, value):
        if action == 'progress':
            self.progress = value
        elif action == 'found':
            self.addresses.append(value)
            self.remove('scan', self._command.domain_name, value)
        elif action == 'fixed':
            if value[0] not in self.fixed:
                self.fixed[value[0]] = []
                self.remove('scan', self._command.domain_name, value[0])
            if value[1] not in self.fixed[value[0]]:
                self.fixed[value[0]].append(value[1])
                self.remove('scan', self._command.domain_name, value[1])
        elif action == 'error':
            self.error = value

        async_to_sync(self.layer.group_send)(
            self.group,
            {
                'type': 'chat_message',
                'message': {
                    action: value
                }
            }
        )

        self.write(self.file, value={
            'progress': self.progress,
            'addresses': self.addresses,
            'fixed': self.fixed,
            'dali_type': self.dali_type,
            'action': self._command.__class__.__name__,
            'error': self.error,
        })

    @property
    def status(self): return self.read(self.file)

    def send_status(self, channel_name):
        async_to_sync(self.layer.send)(channel_name, {
            'type': 'chat_message',
            'message': {
                'status': self.status
            }
        })
